@@ -1,7 +1,7 @@
 //@line 38 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/components/addrbook/content/abCardOverlay.js"
 
 const kNonVcardFields =
-        ["nickNameContainer", "secondaryEmailContainer", "screenNameContainer",
+        ["NickNameContainer", "SecondaryEmailContainer", "ScreenNameContainer",
          "customFields", "allowRemoteContent", "preferDisplayName"];
 
 const kPhoneticFields =
